==> gitlab-11.8.2-1-x86_64.pkg.tar.xz: usr/share/doc/gitlab/CONTRIBUTING.md <==
## Developer Certificate of Origin + License

By contributing to GitLab B.V., You accept and agree to the following terms and
conditions for Your present and future Contributions submitted to GitLab B.V.
Except for the license granted herein to GitLab B.V. and recipients of software
distributed by GitLab B.V., You reserve all right, title, and interest in and to
Your Contributions. All Contributions are subject to the following DCO + License
terms.

[DCO + License](https://gitlab.com/gitlab-org/dco/blob/master/README.md)

All Documentation content that resides under the [doc/ directory](/doc) of this
repository is licensed under Creative Commons:
[CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/).

_This notice should stay as the first item in the CONTRIBUTING.md file._

## Contributing Documentation has been moved

As of July 2018, all the documentation for contributing to the GitLab project has been moved to a new location.
[view the new documentation](doc/development/contributing/index.md) to find the latest information.

## Contribute to GitLab

This [documentation](doc/development/contributing/index.md#contribute-to-gitlab) has been moved.

## Security vulnerability disclosure

This [documentation](doc/development/contributing/index.md#security-vulnerability-disclosure) has been moved.

## Code of Conduct

This [documentation](https://about.gitlab.com/contributing/code-of-conduct/) has been moved.

## Closing policy for issues and merge requests

This [documentation](doc/development/contributing/index.md#closing-policy-for-issues-and-merge-requests) has been moved.

## Helping others

This [documentation](doc/development/contributing/index.md#helping-others) has been moved.

## I want to contribute!

This [documentation](doc/development/contributing/index.md#i-want-to-contribute) has been moved.

## Contribution Flow

This [documentation](doc/development/contributing/index.md) has been moved.

## Workflow labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Type labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Subject labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Team labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Release Scoping labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Priority labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Severity labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

#### Severity impact guidance

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Label for community contributors

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

## Implement design & UI elements

This [documentation](doc/development/contributing/design.md) has been moved.

## Issue tracker

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Issue triaging

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Feature proposals

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Issue tracker guidelines

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Issue weight

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Regression issues

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Technical and UX debt

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Stewardship

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

## Merge requests

This [documentation](doc/development/contributing/merge_request_workflow.md) has been moved.

### Merge request guidelines

This [documentation](doc/development/contributing/merge_request_workflow.md) has been moved.

### Contribution acceptance criteria

This [documentation](doc/development/contributing/merge_request_workflow.md) has been moved.

## Definition of done

This [documentation](doc/development/contributing/merge_request_workflow.md) has been moved.

## Style guides

This [documentation](doc/development/contributing/style_guides.md) has been moved.

==> gitlab-11.11.2-1-x86_64.pkg.tar.xz: usr/share/doc/gitlab/CONTRIBUTING.md <==
## Developer Certificate of Origin + License

By contributing to GitLab B.V., You accept and agree to the following terms and
conditions for Your present and future Contributions submitted to GitLab B.V.
Except for the license granted herein to GitLab B.V. and recipients of software
distributed by GitLab B.V., You reserve all right, title, and interest in and to
Your Contributions. All Contributions are subject to the following DCO + License
terms.

[DCO + License](https://gitlab.com/gitlab-org/dco/blob/master/README.md)

All Documentation content that resides under the [doc/ directory](/doc) of this
repository is licensed under Creative Commons:
[CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/).

_This notice should stay as the first item in the CONTRIBUTING.md file._

## Contributing Documentation has been moved

As of July 2018, all the documentation for contributing to the GitLab project has been moved to a new location.
[View the new documentation](doc/development/contributing/index.md) to find the latest information.

## Contribute to GitLab

This [documentation](doc/development/contributing/index.md#contribute-to-gitlab) has been moved.

## Security vulnerability disclosure

This [documentation](doc/development/contributing/index.md#security-vulnerability-disclosure) has been moved.

## Code of Conduct

This [documentation](https://about.gitlab.com/contributing/code-of-conduct/) has been moved.

## Closing policy for issues and merge requests

This [documentation](doc/development/contributing/index.md#closing-policy-for-issues-and-merge-requests) has been moved.

## Helping others

This [documentation](doc/development/contributing/index.md#helping-others) has been moved.

## I want to contribute!

This [documentation](doc/development/contributing/index.md#i-want-to-contribute) has been moved.

## Contribution Flow

This [documentation](doc/development/contributing/index.md) has been moved.

## Workflow labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Type labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Subject labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Team labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Release Scoping labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Priority labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Severity labels

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

#### Severity impact guidance

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Label for community contributors

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

## Implement design & UI elements

This [documentation](doc/development/contributing/design.md) has been moved.

## Issue tracker

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Issue triaging

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Feature proposals

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Issue tracker guidelines

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Issue weight

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Regression issues

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Technical and UX debt

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

### Stewardship

This [documentation](doc/development/contributing/issue_workflow.md) has been moved.

## Merge requests

This [documentation](doc/development/contributing/merge_request_workflow.md) has been moved.

### Merge request guidelines

This [documentation](doc/development/contributing/merge_request_workflow.md) has been moved.

### Contribution acceptance criteria

This [documentation](doc/development/contributing/merge_request_workflow.md) has been moved.

## Definition of done

This [documentation](doc/development/contributing/merge_request_workflow.md) has been moved.

## Style guides

This [documentation](doc/development/contributing/style_guides.md) has been moved.
